@@ -5,7 +5,7 @@ import cPickle
 
 from gargoyle_launcher_gui import *
 
-CURRENTVERSION = "0.1.3"
+CURRENTVERSION = "0.1.4"
 
 class GLaunch(QtGui.QMainWindow):
     games_dict = {}
@@ -27,9 +27,10 @@ class GLaunch(QtGui.QMainWindow):
         
 
     def doLaunch(self):
-        os.system("cd /home/user/MyDocs/ && /usr/bin/gargoyle \"" 
-                    + str(self.games_dict[self.ui.listWidgetGames.item(self.ui.listWidgetGames.currentRow()).text()]) 
-                    + "\" &")
+        filepath = str(self.games_dict[self.ui.listWidgetGames.item(self.ui.listWidgetGames.currentRow()).text()])
+        commandToRun = "cd /home/user/MyDocs/ && /usr/bin/gargoyle " +  filepath.replace(' ', '\ ') + " &"
+        print "Executing: " + commandToRun
+        os.system(commandToRun)
 
         if(self.closeOnExit):
             self.close()
